#!/usr/bin/python
#############################################################################
# Name:         interfaces.py
# Purpose:      A configurable SSH agent utility for ZOPE3.
#               Interface definitions
# Maintainer:   Torsten Kurbad <t.kurbad@iwm-kmrc.de>
# Copyright:    (c) iwm-kmrc.de KMRC - Knowledge Media Research Center
# License:      GPLv2
#############################################################################
__docformat__ = 'restructuredtext'

from zope.interface import Interface
from zope.schema import Bool, List, Text, TextLine


from zope.i18nmessageid import MessageFactory
_ = MessageFactory('sshagent')


class SSHAgentNotRunning(Exception):
    """The configured SSHAgent executable is not running."""


class IdentityListEmpty(Exception):
    """The list of private keys (identities) is empty. Please, add some."""


class NotAllIdentitiesAdded(Exception):
    """Not all private keys (identities) could be added to the agent."""


class NotAllIdentitiesRemoved(Exception):
    """Not all private keys (identities) could be removed from the agent."""


class ISSHAgent(Interface):
    """Interface definitions for the SSHAgent utility.
    
    Defines methods to handle SSH private keys stored, e.g. in the ZODB.

    """

    identities = List(
        value_type=Text(
            title=_(u'SSH identity')
        ),
        title=_(u'SSH identities'),
        default=[],
        description=_(u'A set of SSH identities (i.e. private keys).'),
        required=False)

    ssh_agent = TextLine(
        title=_(u'SSH agent command'),
        default=u'ssh-agent',
        description=_(u'The name of the SSH agent command.'),
        required=True)

    ssh_add = TextLine(
        title=_(u'SSH add command'),
        default=u'ssh-add',
        description=_(u'The name of the SSH add command.'),
        required=True)

    autoRegister = Bool(
        title=_(u'Autoregister'),
        description=_(u'Automatically register as SSHAgent utility.'),
        default=True,
        required=False)

    def callAgent():
        """Call the requested SSH agent command and read it's environment."""

    def killAgent():
        """Terminate a previously called SSH agent. """

    def addIdentities():
        """Add identies to the currently running agent via the configured SSH
        add command.
        
        """

    def clearIdentities():
        """Remove all identies from the currently running agent."""

    def getEnv():
        """Return the utilities os.environ."""


class ICheckSSHAgent(Interface):
    """Test SSHAgent utility configuration."""

    def checkSSHAgent():
        """Perform a series of test actions (start agent, add keys, ...)."""
